@@ -145,7 +145,7 @@ def singlechoice(title='', msg='', arg=('a', 'b', 'c')):
     window = []
     v = StringVar()
     for x in arg:
-        window.append(Radiobutton(tk, text=x, variable=v))
+        window.append(Radiobutton(tk, text=x, variable=v, value=x))
     for x in window:
         x.pack()
     Button(tk, text='Finish', command=tk.quit).pack()
@@ -174,11 +174,11 @@ def singlechoices(title='', msg='', arg=(('a', 'b', 'c'), ('e', 'f', 'g'))):
         lf_list.append(LabelFrame(tk, text=str(times + 1)))
         # LabelFrame
         for y in x:
-            window.append(Radiobutton(lf_list[times], text=y, variable=value_list[times]))
+            window.append(Radiobutton(lf_list[times], text=y, variable=value_list[times], value=y))
         # Tkinter
         times += 1
     for x in window:
-        z.pack()
+        x.pack()
     for x in lf_list:
         x.pack()
     # Checkbutton
