@@ -17,10 +17,10 @@ def computer():
     %s''' % p.version())
 
 def python():
-    print('===== ' + str(sys.version_info[0]) + '.' + str(sys.version_info[1]) + '.' + str(sys.version_info[2]) + ' =====')
-    print('''Python Version : ''')
+    print('===== Python ' + str(sys.version_info[0]) + '.' + str(sys.version_info[1]) + '.' + str(sys.version_info[2]) + ' =====')
+    print('''Version : ''')
     print(4 * ' ',end='')
     print(sys.version)
-    print('''Python Build :
+    print('''Build :
     ''',end='')
     print(p.python_build())
